==> geoserver-manager-1.5.1-sources.jar: it/geosolutions/geoserver/rest/decoder/utils/JDOMBuilder.java <==
/*
 *  GeoServer-Manager - Simple Manager Library for GeoServer
 *  
 *  Copyright (C) 2007,2011 GeoSolutions S.A.S.
 *  http://www.geo-solutions.it
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package it.geosolutions.geoserver.rest.decoder.utils;

import java.io.IOException;
import java.io.StringReader;

import org.jdom.Document;
import org.jdom.Element;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 *
 * @author ETj (etj at geo-solutions.it)
 */
public class JDOMBuilder {

    private final static Logger LOGGER = LoggerFactory.getLogger(JDOMBuilder.class);

    public static Element buildElement(String response) {
        if(response == null)
            return null;

        try{
			SAXBuilder builder = new SAXBuilder();
			Document doc = builder.build(new StringReader(response));
			return  doc.getRootElement();
		} catch (JDOMException ex) {
			LOGGER.warn("Ex parsing response", ex);
		} catch (IOException ex) {
			LOGGER.warn("Ex loading response", ex);
		}

		return null;
    }

}

==> geoserver-manager-1.8.5-sources.jar: it/geosolutions/geoserver/rest/decoder/utils/JDOMBuilder.java <==
/*
 *  GeoServer-Manager - Simple Manager Library for GeoServer
 *  
 *  Copyright (C) 2007,2011 GeoSolutions S.A.S.
 *  http://www.geo-solutions.it
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package it.geosolutions.geoserver.rest.decoder.utils;

import java.io.IOException;
import java.io.StringReader;

import org.jdom.Document;
import org.jdom.Element;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * <p>JDOMBuilder class.</p>
 *
 * @author ETj (etj at geo-solutions.it)
 * @version $Id: $
 */
public class JDOMBuilder {

    private final static Logger LOGGER = LoggerFactory.getLogger(JDOMBuilder.class);

    /**
     * <p>buildElement</p>
     *
     * @param response a {@link java.lang.String} object.
     * @return a {@link org.jdom.Element} object.
     */
    public static Element buildElement(String response) {
        if(response == null)
            return null;

        try{
			SAXBuilder builder = new SAXBuilder();
			Document doc = builder.build(new StringReader(response));
			return  doc.getRootElement();
		} catch (JDOMException ex) {
			LOGGER.warn("Ex parsing response", ex);
		} catch (IOException ex) {
			LOGGER.warn("Ex loading response", ex);
		}

		return null;
    }

}
